# Contributing

- Open an issue or feature request: https://github.com/pmbrull/open-stats/issues
- You can build the code locally with `make install`. Environment virtualization is recommended.
- Check the test application with `make test`
- Make sure that the code is properly formatted with `make py_format`
- Check that there are no linting errors with `make lint`
